@@ -3,13 +3,14 @@ Main interface for kinesisanalyticsv2 service.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.kinesisanalyticsv2 import (
+    from mypy_boto3_kinesisanalyticsv2 import (
         Client,
         KinesisAnalyticsV2Client,
         ListApplicationSnapshotsPaginator,
         ListApplicationsPaginator,
-        )
+    )
 
     session = boto3.Session()
 
@@ -18,16 +19,16 @@ Usage::
 
     list_application_snapshots_paginator: ListApplicationSnapshotsPaginator = client.get_paginator("list_application_snapshots")
     list_applications_paginator: ListApplicationsPaginator = client.get_paginator("list_applications")
+    ```
 """
-from mypy_boto3_kinesisanalyticsv2.client import (
-    KinesisAnalyticsV2Client as Client,
-    KinesisAnalyticsV2Client,
-)
+from mypy_boto3_kinesisanalyticsv2.client import KinesisAnalyticsV2Client
 from mypy_boto3_kinesisanalyticsv2.paginator import (
     ListApplicationSnapshotsPaginator,
     ListApplicationsPaginator,
 )
 
+Client = KinesisAnalyticsV2Client
+
 
 __all__ = (
     "Client",
